<?php

namespace Garradin;

use Garradin\Plugin\RecusFiscaux\Utils;

// ------------------------------------------------------------------------
// opérations communes
// ------------------------------------------------------------------------

// champs pour le nom et prénom
$confNoms = Utils::getChampsNom($config, $plugin);
uasort($confNoms, function ($a, $b)
{
    return $a->position - $b->position;
});
$champsNom = array();
foreach ($confNoms as $nom => $champ)
{
    if ($champ->position != 0) { $champsNom[] = $nom; }
}

// membres donateurs
$_SESSION['membresDonateurs'] = Utils::getDonateurs($_SESSION['annee_recu'],
                                                    $champsNom);

// comparaison de lignes de versements
// comparer 2 lignes selon le nom
function comparerNoms($ligne1, $ligne2)
{
    return
        $_SESSION['membresDonateurs'][$ligne1->idUser]->rang
        -
        $_SESSION['membresDonateurs'][$ligne2->idUser]->rang;
}

// comparer 2 activités par leur libellé
function comparerActivites($ligne1, $ligne2)
{
    return strcoll(
        $_SESSION['lesActivites'][$_SESSION['lesTarifs'][$ligne1->idTarif]->idActivite]->label,
        $_SESSION['lesActivites'][$_SESSION['lesTarifs'][$ligne2->idTarif]->idActivite]->label);
}

// comparer 2 lignes selon la date
function comparerDate($ligne1, $ligne2)
{
    return
        strtotime($ligne1->date) - strtotime($ligne2->date);
}

// comparer 2 lignes selon un champ numérique entier
function comparerChamp($ligne1, $ligne2, $champ)
{
    return $ligne1->$champ - $ligne2->$champ;
}

// ------------------------------------------------------------------------
// fonctions pour l'affichage
// ------------------------------------------------------------------------

// afficher les informations d'une activité et d'un tarif
$tpl->register_function('afficher_debut_tarif', function ($params)
{
    $versement = $params['versement'];
    $idTarif = $versement->idTarif;
    $tarif = $_SESSION['lesTarifs'][$idTarif];
    $idActivite = $tarif->idActivite;
    $activite = $_SESSION['lesActivites'][$idActivite];

    $out = '<details class="activite" open="open">
        <summary class="activite">';
    $out .= sprintf('
            <h3>Activité « %s »</h3>', $activite->label);
    if (!empty($activite->description)) {
        $out .= sprintf('
                <h4>%s</h4>', $activite->description);
    }
    $out .= sprintf('
                <h4>tarif « %s »', $tarif->label);
    if ($tarif->montant > 0) {
        $out .= sprintf(' montant : %.2f €', $tarif->montant/100);
    } else {
        $out .= ' montant : libre';
    }
    $out .= '</h4>
          </summary>';
    return $out;
});

// Afficher les informations d'une personne
$tpl->register_function('afficher_debut_personne', function ($params)
{
    $idUser = $params['user'];
    $idVersement = $params['idVersement'];

    $personne = $_SESSION['membresDonateurs'][$idUser];
    $out = '<details class="personne" open="open">
        <summary class="personne">
        <h4 class="personne">';
    $out .= sprintf('
            <input type="checkbox" id="check_%s"',
                    $idVersement);
    $out .= sprintf(' onclick="cocherDecocherPersonne(check_%s, total_%s)" />',
                    $idVersement,
                    $idVersement);
    $out .= sprintf('
            <label for="check_%s">',
                    $idVersement);
    $out .= sprintf('%s : <span class="total" id="total_%s">0,00 €</span>',
                   $personne->nomPrenom,
                   $idVersement);
    $out .= '</label></h4></summary>';
    $out .= sprintf('
            <fieldset class="versements" id="versements_%s">',
                    $idVersement);
    return $out;
});

// afficher un versement
$tpl->register_function('afficher_versement', function ($params)
{
    $versement = $params['versement'];
    $idVersement = $params['idVersement'];
    $num = $params['num'];
    $rang = $params['rang'];

    $out = '<div class="';
    $out .= ($rang%2==0) ? 'pair">' : 'impair">';
    $out .= sprintf('
                <input type="checkbox"
                    class="check_%s"
                    id="check_%s_%s"
                    name="selected[]"
                    value="%s"
                    onclick="cocherDecocherVersement(check_%s_%s, total_%s)" />',
                    $idVersement,
                    $idVersement, $rang,
                    $num,
                    $idVersement, $rang, $idVersement
    );
    $out .= sprintf('
                <label for="check_%s_%s"><span class="montant">%.2f</span>',
                    $idVersement,
                    $rang,
                    $versement->versement/100
    );
    $out .= sprintf('
                    <span>%s</span>',
                    date_format(date_create($versement->date),"d/m/Y"));
    $out .= sprintf('
                    <span>%s</span>',
                    $versement->compte);
    $out .= sprintf('
                </label>
                </div>'
    );
    return $out;
});

// ------------------------------------------------------------------------
// aiguillage
// ------------------------------------------------------------------------

if ($_GET['action'] == 'personne') {
    require('versements_personnes.php');
} else {
    require('versements_activites.php');
}
